@@ -4,14 +4,11 @@ testthat::test_that(desc = "simple_slope: two-way-interaction", {
     response_variable = "Sepal.Length",
     predictor_variable = c(Sepal.Width, Petal.Width),
     two_way_interaction_factor = c(Sepal.Width, Petal.Width),
-    quite = T
+    quite = TRUE
   )
 
   summary <- simple_slope(
-    data = iris[1:4],
-    model = model,
-    two_way_interaction_factor = c("Sepal.Width", "Petal.Width")
-  )
+    model = model)
 
   expect_equal(c(summary$simple_slope_df[1])[[1]], c("Low", "Mean", "High"))
 })
@@ -22,13 +19,11 @@ testthat::test_that(desc = "simple_slope: three-way-interaction", {
     response_variable = "Sepal.Length",
     predictor_variable = c(Sepal.Width, Petal.Width),
     three_way_interaction_factor = c(Sepal.Width, Petal.Width, Petal.Length),
-    quite = T
+    quite = TRUE
   )
 
   summary <- simple_slope(
-    data = iris[1:4],
     model = model,
-    three_way_interaction_factor = c("Sepal.Width", "Petal.Width", "Petal.Length")
   )
 
   expect_equal(c(summary$simple_slope_df[1])[[1]], c("Low", "", "", "Mean", "", "", "High", "", ""))
